from datetime import date

from myst_parser import __version__

project = "Project"
copyright = f"{date.today().year}, Blake Naccarato"  # noqa: A001
version = __version__
master_doc = "index"
language = "en"
extensions = ["myst_parser", "sphinx_design"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
html_theme = "sphinx_book_theme"



"""Bump `pyproject.toml` with changes in `requirements.txt`"""

from pathlib import Path

import toml

REQUIREMENTS = Path("requirements.txt")
PYPROJECT = Path("pyproject.toml")

with open(REQUIREMENTS) as file:
    dependencies = [
        line.rstrip() for line in file if line != "\n" and not line.startswith("#")
    ]


with open(PYPROJECT) as file:
    content = toml.load(file)
    content["project"]["dependencies"] = dependencies

with open(PYPROJECT, "w") as file:
    toml.dump(content, file)



"""Runs after `pythonrc.py` in IPython, and runs alone for Jupyter notebooks.

Avoid activating Rich features that break functionality in notebooks.
"""


def main():
    if is_notebook():
        from rich import inspect, traceback

        traceback.install()


# https://stackoverflow.com/a/39662359
def is_notebook() -> bool:
    try:
        shell = get_ipython().__class__.__name__  # pyright: ignore
        return shell == "ZMQInteractiveShell"
    except NameError:
        return False  # Probably standard Python interpreter


main()
